import {themes as prismThemes} from 'prism-react-renderer';
import type {Config} from '@docusaurus/types';
import type * as Preset from '@docusaurus/preset-classic';

const config: Config = {
  title: 'nick-slowinski.de',
  tagline: 'Pinguine sind cool.',
  favicon: 'img/favicon.ico',

  // Set the production url of your site here
  url: 'https://www.nick-slowinski.de',
  // Set the /<baseUrl>/ pathname under which your site is served
  // For GitHub pages deployment, it is often '/<projectName>/'
  baseUrl: '/',

  // GitHub pages deployment config.
  // If you aren't using GitHub pages, you don't need these.
  organizationName: 'nick-slowinski.de', // Usually your GitHub org/user name.
  projectName: 'www', // Usually your repo name.

  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'warn',

  // Even if you don't use internationalization, you can use this field to set
  // useful metadata like html lang. For example, if your site is Chinese, you
  // may want to replace "en" with "zh-Hans".
  i18n: {
    defaultLocale: 'de',
    locales: ['de'],
  },

  presets: [
    [
      'classic',
      {
        docs: {
          path: 'services',
          routeBasePath: 'services',
          sidebarPath: './sidebarsServices.ts',
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          //editUrl:
          //  'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        blog: {
          showReadingTime: true,
          routeBasePath: '/',
          blogSidebarTitle: 'Beiträge',
          blogSidebarCount: 'ALL',
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          //editUrl:
          //  'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        theme: {
          customCss: './src/css/custom.css',
        },
      } satisfies Preset.Options,
    ],
  ],
  plugins: [
    [ require.resolve("@easyops-cn/docusaurus-search-local"),
      ({
        hashed: true,
        language: ["de"],
        docsDir: ["services", "info"],
        indexPages: true,
      }),
    ],
    [
      '@docusaurus/plugin-content-docs',
      {
        id: 'info',
        path: 'info',
        routeBasePath: 'info',
        sidebarPath: './sidebarsInfo.ts',
        // ... other options
      },
    ],
  ],
  themeConfig: {
    // Replace with your project's social card
    image: 'img/docusaurus-social-card.jpg',
    navbar: {
      title: 'nick-slowinski.de',
      items: [
        {to: '/', label: 'Blog', position: 'left'},
        {
          type: 'docSidebar',
          sidebarId: 'servicesSidebar',
          position: 'left',
          label: 'Dienste',
        },
        {
          type: 'docSidebar',
          docsPluginId: 'info',
          sidebarId: 'infoSidebar',
          position: 'left',
          label: 'Informationen',
        },
      ],
    },
    footer: {
      style: 'dark',
      links: [
        {
          title: 'Dienste',
          items: [
            {
              label: 'Community Forum',
              to: 'https://community.nick-slowinski.de',
            },
            {
              label: 'Forge',
              to: 'https://forge.nick-slowinski.de',
            },
            {
              label: 'Passwort-Manager',
              to: 'https://vault.nick-slowinski.de',
            },
            {
              label: 'nsAccounts (Kontoverwaltung)',
              to: 'https://accounts.nick-slowinski.de/realms/nick-slowinski_de/account',
            },
            {
              label: 'TeamSpeak',
              to: 'ts3server://nick-slowinski.de',
            },
            {
              label: 'Alle Dienste entdecken',
              to: '/services/daten',
            }
          ],
        },
        {
          title: 'Support',
          items: [
            {
              label: 'Statusseite',
              to: 'https://status.nick-slowinski.de',
            },
            {
              label: 'E-Mail',
              to: 'mailto:support@nick-slowinski.de',
            },
            {
              label: 'Community Forum',
              to: 'https://community.nick-slowinski.de/c/support/5',
            },
          ],
        },
        {
          title: 'Rechtliches',
          items: [
            {
              label: 'Impressum',
              to: '/impressum',
            },
            {
              label: 'Datenschutzerklärung',
              href: '/datenschutzerklaerung',
            },
          ],
        },
      ],
      copyright: `Dieses Werk ist unter der <a href="https://creativecommons.org/licenses/by/4.0/deed.de" target="_blank">Creative Commons Namensnennung 4.0 International (CC BY 4.0)</a> lizenziert, sofern nicht anders angegeben.`,
    },
    prism: {
      theme: prismThemes.github,
      darkTheme: prismThemes.dracula,
    },
  } satisfies Preset.ThemeConfig,
};

export default config;